Register a new account
======================

.. _core-user-registration:

Public registration
-------------------

If public registration is enabled on the AlekSIS instance, you can click the
``Signup`` button located in the navigation sidebar and register for an
AlekSIS account.

.. image:: ../_static/signup.png
  :width: 100%
  :alt: Signup formular

If enabled, you have to verify your email address after signup. To do so, click
on the link you received on the email address you entered in the signup form.

.. note::
   Normally, AlekSIS does not allow public registratio, and all accounts are
   centrally managed by administrators. Public registration is an optional
   feature that has to be enabled by adminsitrators after careful consideration.

Using an invitation code
------------------------

If you have an invitation code, click ``Accept invitation`` in the sidebar and
enter it. You will be redirected to the signup form.

.. image:: ../_static/accept_invite.png
  :width: 100%
  :alt: Accept invitation

If you've received an invitation link (e.g. via email), clicking the link
will redirect you to the signup form automatically.
